==> deepin-boot-maker_5.6.12+dfsg.orig.tar.gz: deepin-boot-maker_5.6.12+dfsg/src/translations/deepin-boot-maker_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Datenträgerformatierungsfehler: Bitte neu formatieren</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Fehler beim Einhängen des Datenträgers: Bitte überprüfen Sie, ob die Verbindung zum Datenträger korrekt ist oder der Datenträger korrekt in das Laufwerk eingelegt wurde. Starten Sie anschließend den Rechner neu.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Fehler beim Entpacken des Abbilds: Bitte prüfen Sie die MD5-Prüfsumme des Abbilds und stellen Sie sicher, dass es sich um ein vollständiges unbeschädigtes Abbild handelt.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Interner Fehler</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>Drag an ISO image file here</source>
        <translation>Ziehen Sie eine ISO-Abbild-Datei hierher</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="145"/>
        <source>OR</source>
        <translation>oder</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>ISO-Abbild auswählen</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="211"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="297"/>
        <source>Reselect an ISO image file</source>
        <translation>Ein neues ISO-Abbild auswählen</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="234"/>
        <source>Illegal ISO image file</source>
        <translation>Unzulässige ISO-Abbild-Datei</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="438"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>ISO-Datei wird erkannt, bitte warten...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>Wird gebrannt</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>Wird gebrannt, bitte warten ...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Entfernen Sie während des Vorgangs nicht den Datenträger und fahren Sie den Computer nicht herunter</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Wechseldatenträger</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="223"/>
        <location filename="../libdbm/util/utils.cpp" line="369"/>
        <source>Removable disk</source>
        <translation>Wechseldatenträger</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Reboot now</source>
        <translation>Jetzt neu starten</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="120"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="68"/>
        <source>Successful</source>
        <translation>Erfolgreich</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="217"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Das Fehlerprotokoll wird automatisch mit der Rückmeldung hochgeladen. Ohne Ihre Rückmeldung können wir uns nicht verbessern.</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="218"/>
        <source>Submit Feedback</source>
        <translation>Rückmeldung senden</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="241"/>
        <source>After-Sale Services</source>
        <translation>Kundendienst</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="254"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="262"/>
        <source>Sorry, process failed</source>
        <translation>Entschuldigung, Vorgang fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="263"/>
        <source>Process failed</source>
        <translation>Vorgang fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Daten werden verifiziert und das Medium sicher ausgeworfen. Bitte warten ...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="95"/>
        <source>Select a partition</source>
        <translation>Wählen Sie eine Partition aus</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="122"/>
        <source>Format the partition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="171"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="175"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Bei der Formatierung werden alle Daten auf der Partition gelöscht, sie kann aber die Erfolgsquote erhöhen, bitte bestätigen Sie dies, bevor Sie fortfahren</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="368"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Beim Formatieren der Partition werden alle Daten überschrieben, bitte erstellen Sie eine Sicherungskopie, bevor Sie fortfahren.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="402"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Datenträgerformatierungsfehler: Bitte formatieren Sie die Partition mit FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="156"/>
        <source>No disk available</source>
        <translation>Kein Datenträger verfügbar</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="365"/>
        <source>Format Partition</source>
        <translation>Partition formatieren</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="372"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="374"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_5.10.0+dfsg2.orig.tar.gz: deepin-boot-maker-5.10.0+dfsg2/src/translations/deepin-boot-maker_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Datenträgerformatierungsfehler: Bitte neu formatieren</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Fehler beim Einhängen des Datenträgers: Bitte überprüfen Sie, ob die Verbindung zum Datenträger korrekt ist oder der Datenträger korrekt in das Laufwerk eingelegt wurde. Starten Sie anschließend den Rechner neu.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Fehler beim Entpacken des Abbilds: Bitte prüfen Sie die MD5-Prüfsumme des Abbilds und stellen Sie sicher, dass es sich um ein vollständiges unbeschädigtes Abbild handelt.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Interner Fehler</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="116"/>
        <source>Drag an ISO image file here</source>
        <translation>Ziehen Sie eine ISO-Abbild-Datei hierher</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>OR</source>
        <translation>oder</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="82"/>
        <location filename="../app/view/isoselectview.cpp" line="140"/>
        <source>Select an ISO image file</source>
        <translation>ISO-Abbild auswählen</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="170"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="225"/>
        <source>Reselect an ISO image file</source>
        <translation>Ein neues ISO-Abbild auswählen</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="188"/>
        <source>Illegal ISO image file</source>
        <translation>Unzulässige ISO-Abbild-Datei</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="328"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>ISO-Datei wird erkannt, bitte warten...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Burning</source>
        <translation>Wird gebrannt</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="63"/>
        <source>Burning, please wait...</source>
        <translation>Wird gebrannt, bitte warten ...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="71"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Entfernen Sie während des Vorgangs nicht den Datenträger und fahren Sie den Computer nicht herunter</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="85"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Wechseldatenträger</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="224"/>
        <location filename="../libdbm/util/utils.cpp" line="370"/>
        <source>Removable disk</source>
        <translation>Wechseldatenträger</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="122"/>
        <source>Boot Maker</source>
        <translation>Boot Maker</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="104"/>
        <source>Reboot now</source>
        <translation>Jetzt neu starten</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="56"/>
        <source>Successful</source>
        <translation>Erfolgreich</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="95"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="169"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Das Fehlerprotokoll wird automatisch mit der Rückmeldung hochgeladen. Ohne Ihre Rückmeldung können wir uns nicht verbessern.</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="170"/>
        <source>Submit Feedback</source>
        <translation>Rückmeldung senden</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="193"/>
        <source>After-Sale Services</source>
        <translation>Kundendienst</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="206"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="214"/>
        <source>Sorry, process failed</source>
        <translation>Entschuldigung, Vorgang fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="215"/>
        <source>Process failed</source>
        <translation>Vorgang fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Daten werden verifiziert und das Medium sicher ausgeworfen. Bitte warten ...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="92"/>
        <source>Select a partition</source>
        <translation>Wählen Sie eine Partition aus</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="117"/>
        <source>Format the partition</source>
        <translation>Formatieren der Partition</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="170"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Bei der Formatierung werden alle Daten auf der Partition gelöscht, sie kann aber die Erfolgsquote erhöhen, bitte bestätigen Sie dies, bevor Sie fortfahren</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="380"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="391"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Beim Formatieren der Partition werden alle Daten überschrieben, bitte erstellen Sie eine Sicherungskopie, bevor Sie fortfahren.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="407"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Datenträgerformatierungsfehler: Bitte formatieren Sie die Partition mit FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>No disk available</source>
        <translation>Kein Datenträger verfügbar</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="358"/>
        <source>Format Partition</source>
        <translation>Partition formatieren</translation>
    </message>
</context>
</TS>
